// Copyright (c) 2023, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:js_interop';

import 'webgl1.dart';

@JS('WEBGL_compressed_texture_etc')
@staticInterop
class WEBGL_compressed_texture_etc {
  external static GLenum get COMPRESSED_R11_EAC;
  external static GLenum get COMPRESSED_SIGNED_R11_EAC;
  external static GLenum get COMPRESSED_RG11_EAC;
  external static GLenum get COMPRESSED_SIGNED_RG11_EAC;
  external static GLenum get COMPRESSED_RGB8_ETC2;
  external static GLenum get COMPRESSED_SRGB8_ETC2;
  external static GLenum get COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2;
  external static GLenum get COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2;
  external static GLenum get COMPRESSED_RGBA8_ETC2_EAC;
  external static GLenum get COMPRESSED_SRGB8_ALPHA8_ETC2_EAC;
}
